@@ -20,20 +20,18 @@
 #marked as so. 2.) The original of this module must not be misrepresented;
 #you cannot claim this module is yours.
 
-'''Notes: for imported() and modx_imported(), dependencies of modx itself as
-this feature will be added in a future update, presumably update 2.0.0.
-
-vcompat() checks for most issues for Python versions 2.0 - 3.12 and not all.
+'''vcompat() checks for most issues for Python versions 2.0 - 3.12 and not all.
 If every issue were to be included, the rules alone would be about 1500 lines
 and the rest of the function would be 200 lines-ish. Most of the major issues
-are included in vcompat(). Only less, very rare problems are left out.
+are included in vcompat(). Only less common, very rare problems are left out.
 
 Created by: Austin Wang. Created on: September 19, 2025. Last updated:
-October 5, 2025'''
+November 20, 2025'''
 
-_version_= "1.8.3"
+_version_= "2.0.0"
 
 import sys, importlib, pkgutil, random, builtins, ast, importlib.util, os, tokenize, io
+import time, tracemalloc, inspect, textwrap, math
 from pathlib import Path
 from packaging import version
 
@@ -87,7 +85,7 @@ modules = [
         'struct', 'subprocess', 'symtable', 'tabnanny', 'tarfile', 'tempfile', 'textwrap',
         'threading', 'timeit', 'token', 'tokenize', 'trace', 'traceback', 'tracemalloc', 'turtle',
         'types', 'typing', 'uuid', 'warnings', 'wave', 'weakref', 'webbrowser', 'zipapp', 'zipimport',
-        '_future_', '_hello_', '_phello_', "atexit", "mmap",
+        "atexit", "mmap",
         'autocomplete','autocomplete_w','autoexpand','browser','build',
         'calltip','calltip_w','codecontext','colorizer',
         'config','config_key','configdialog','debugger','debugger_r',
@@ -109,14 +107,10 @@ modules = [
         '_blake2', '_pickle', '_json', '_zoneinfo', '_opcode', 'cmath', 'numbers',
         '_codecs_cn', '_codecs_hk', '_codecs_iso2022', '_codecs_jp', '_codecs_kr',
         '_codecs_tw', '_interpchannels', '_interpqueues', '_interpreters',
-        '_multibytecodec', '_sha2', '_sha3', '_suggestions', 'faulthandler', 'xxsubtype'
-        ]
+        '_multibytecodec', '_sha2', '_sha3', '_suggestions', 'faulthandler',
+        'xxsubtype','time']
 
-#########################
-# Bulk import functions #
-#########################
-
-def import_all():
+def importall():
     """Import almost every module in Python that is given when downloading Python."""
     import builtins
     caller_globals = globals()
@@ -136,18 +130,12 @@ def import_all():
     finally:
         builtins._import_ = _tracking_import
     
-    # Show results
-    print(f"import_all() Results:")
-    print(f"SUCCESS: {len(success)} modules")
-    print(f"FAILED: {len(failed)} modules")
     if failed:
-        print("\nFailed imports:")
-        for mod, error in failed[:10]:  # Show first 10 failures
+        print(f"{len(failed)} modules failed to import:")
+        for mod, error in failed[:10]:
             print(f"   {mod}: {error}")
-        if len(failed) > 10:
-            print(f"   ... and {len(failed) - 10} more")
 
-def import_random(n):
+def importrandom(n):
     """Import n random stdlib modules and track them."""
     import builtins
     caller_globals = globals()
@@ -168,20 +156,12 @@ def import_random(n):
     finally:
         builtins._import_ = _tracking_import
     
-    # Show results
-    print(f" import_random({n}) Results:")
-    print(f" REQUESTED: {len(chosen)} modules")
-    print(f" SUCCESS: {len(success)} modules") 
-    print(f" FAILED: {len(failed)} modules")
     if failed:
-        print("\nFailed imports:")
-        for mod, error in failed:
+        print(f"{len(failed)} modules failed to import:")
+        for mod, error in failed[:10]:
             print(f"   {mod}: {error}")
-    
-    return success
 
-
-def import_external():
+def importexternal():
     """Import all installed third-party modules (not in stdlib list)."""
     import builtins
     caller_globals = globals()
@@ -189,30 +169,69 @@ def import_external():
     builtins._import_ = _original_import
     success = []
     failed = []
+    
+    # Additional methods to find third-party modules
+    third_party_modules = set()
+    
     try:
+        # Method 1: pkgutil.iter_modules (original)
         for finder, name, ispkg in pkgutil.iter_modules():
             if name not in stdlib_set:
-                try:
-                    # Import AND add to caller's globals
-                    module_obj = importlib.import_module(name)
-                    caller_globals[name] = module_obj
-                    _imported_by_modx.add(name.partition('.')[0])
-                    success.append(name)
-                except Exception as e:
-                    failed.append((name, str(e)))
+                third_party_modules.add(name)
+        
+        # Method 2: Check site-packages directories
+        for path in sys.path:
+            if 'site-packages' in path or 'dist-packages' in path:
+                if os.path.exists(path):
+                    for item in os.listdir(path):
+                        if (item.endswith('.py') or 
+                            (os.path.isdir(os.path.join(path, item)) and 
+                             not item.startswith('__'))):
+                            mod_name = item.replace('.py', '')
+                            if (mod_name not in stdlib_set and 
+                                mod_name not in third_party_modules and
+                                mod_name.isidentifier()):
+                                third_party_modules.add(mod_name)
+        
+        # Method 3: Check pip list (if available)
+        try:
+            import subprocess
+            result = subprocess.run([sys.executable, '-m', 'pip', 'list', '--format=freeze'], 
+                                  capture_output=True, text=True, timeout=10)
+            if result.returncode == 0:
+                for line in result.stdout.splitlines():
+                    if '==' in line:
+                        mod_name = line.split('==')[0].strip()
+                        if (mod_name not in stdlib_set and 
+                            mod_name not in third_party_modules and
+                            mod_name.isidentifier()):
+                            third_party_modules.add(mod_name)
+        except:
+            pass  # pip not available or failed
+        
+        # Try to import all collected third-party modules
+        for name in sorted(third_party_modules):
+            try:
+                # Import AND add to caller's globals
+                module_obj = importlib.import_module(name)
+                caller_globals[name] = module_obj
+                _imported_by_modx.add(name.partition('.')[0])
+                success.append(name)
+            except Exception as e:
+                failed.append((name, str(e)))
+                
     finally:
         builtins._import_ = _tracking_import
     
-    # Show results
-    print(f" import_external() Results:")
-    print(f" SUCCESS: {len(success)} third-party modules")
-    print(f" FAILED: {len(failed)} modules")
+    print(f"Successfully imported {len(success)} third-party modules")
     if failed:
-        print("\nFirst 10 failures:")
-        for mod, error in failed[:10]:
+        print(f"{len(failed)} modules failed to import:")
+        for mod, error in failed[:10]:  # Show first 10 failures
             print(f"   {mod}: {error}")
+        if len(failed) > 10:
+            print(f"   ... and {len(failed) - 10} more")
 
-def import_screen():
+def importscreen():
     """Import common screen/GUI/game modules if available."""
     import builtins
     caller_globals = globals()
@@ -233,16 +252,12 @@ def import_screen():
     finally:
         builtins._import_ = _tracking_import
     
-    # Show results
-    print(f" import_screen() Results:")
-    print(f" SUCCESS: {len(success)} GUI modules")
-    print(f" FAILED: {len(failed)} modules")
     if failed:
-        print("\nFailed imports:")
-        for mod, error in failed:
+        print(f"{len(failed)} modules failed to import:")
+        for mod, error in failed[:10]:
             print(f"   {mod}: {error}")
 
-def import_letter(letter):
+def importletter(letter):
     """Import every stdlib module from ModX 'modules' list
 whose name starts with given letter."""
     import builtins
@@ -265,20 +280,10 @@ whose name starts with given letter."""
     finally:
         builtins._import_ = _tracking_import
     
-    # Show results
-    print(f" import_letter('{letter}') Results:")
-    print(f" SUCCESS: {len(success)} modules starting with '{letter}'")
-    print(f" FAILED: {len(failed)} modules")
     if failed:
-        print("\nFailed imports:")
-        for mod, error in failed:
+        print(f"{len(failed)} modules failed to import:")
+        for mod, error in failed[:10]:
             print(f"   {mod}: {error}")
-    
-    return success
-
-######################
-# Data and reporting #
-######################
 
 def modfunctions(module_name):
     """Show how many and what functions a module has without importing it."""
@@ -382,38 +387,42 @@ def modclasses(module_name):
     except Exception as e:
         print(f"Error analyzing module: {e}")
 
-def list_importall():
+def listimportall():
     """Return the list of modules that import_all() would import."""
     return modules
 
-def modules_loaded():
+def modsloaded():
     """Show how many modules are currently loaded in sys.modules."""
     return len(sys.modules)
 
 def imported():
-    """Show all modules imported since ModX loaded
-(user + ModX + dependencies (excluding ModX dependencies))."""
+    """Show all modules imported since ModX loaded (user + ModX + dependencies)."""
     current = set(sys.modules.keys())
     new_since = current - _initial_modules
 
-    # Filter out modx internals and noise
-    filtered_modules = set()
-    for module_name in new_since:
-        if (module_name == 'modx' or 
-            module_name.startswith('modx.') or
-            module_name.startswith('test.') or
-            module_name.startswith('_test') or
-            module_name in ['_main_', 'sys', 'builtins']):
-            continue
-        filtered_modules.add(module_name)
+    filtered_modules = {
+        m for m in new_since
+        if not (m.startswith('test.') or m.startswith('_test') or m in ['_main_', 'sys', 'builtins'])
+    }
+
+    # Include ModX dependencies explicitly
+    modx_spec = importlib.util.find_spec("modx")
+    if modx_spec and modx_spec.origin and modx_spec.origin.endswith(".py"):
+        try:
+            with open(modx_spec.origin, "r", encoding="utf-8") as f:
+                code = f.read()
+            deps = {w.split()[1].strip(',') for w in code.splitlines() if w.strip().startswith("import ")}
+            filtered_modules |= deps
+        except Exception:
+            pass
+
     sorted_modules = sorted(filtered_modules)
     print("Modules imported after ModX load (user + ModX + dependencies):")
     for name in sorted_modules:
         print("-", name)
     print(f"\nTotal modules imported after ModX load: {len(sorted_modules)}")
 
-
-def modx_imported():
+def modximported():
     """Show ONLY the modules directly imported via ModX functions."""
     shown = sorted(_imported_by_modx)
     print("Modules imported directly via ModX (excluding dependencies):")
@@ -438,10 +447,6 @@ modules that have NOT been imported yet."""
     
     return sorted(unimported)
 
-############################
-# Tracking and Information #
-############################
-
 def dependencies(module_name):
     """Show what other modules a specific module depends on without importing it."""
     import re
@@ -479,8 +484,8 @@ def dependencies(module_name):
                 except SyntaxError:
                     # Fallback to regex for compiled modules or syntax issues
                     imports = re.findall(r'^(?:import|from)\s+([\w\.]+)', source_code, re.MULTILINE)
-                    for imp in imports:
-                        dependencies.add(imp.split('.')[0])
+                    for import_name in imports:
+                        dependencies.add(import_name.split('.')[0])
                         
             except (UnicodeDecodeError, FileNotFoundError, IOError):
                 print("   (Source not readable)")
@@ -509,7 +514,7 @@ def dependencies(module_name):
     except Exception as e:
         print(f"Error analyzing module: {e}")
 
-def search_modules(keyword):
+def searchmodules(keyword):
     """Search for modules whose names contain the keyword."""
     keyword = keyword.lower()
     return [m for m in modules if keyword in m.lower()]
@@ -530,12 +535,11 @@ def info(module_name):
     for line in doc:
         print(line)
 
-def is_imported(module_name: str):
+def isimported(module_name: str):
     """
     Check if a module is imported in the caller's globals.
     True  -> currently imported in shell globals
     False -> exists but not imported yet
-    'Module X doesn't exist.' -> if module does not exist
     """
     import importlib.util, inspect
     frame = inspect.currentframe().f_back
@@ -752,7 +756,6 @@ def vcompat(module_name, python_version=None):
             warnings[key] = label
 
     def _check_if_problematic(rule, targets):
-        """Not designed for public use"""
         if "removed_in" in rule:
             removed_ver = version.parse(rule["removed_in"])
             return any(target >= removed_ver for target in targets)
@@ -939,38 +942,225 @@ def vcompat(module_name, python_version=None):
         print("-" * 80)
         for feat, (ver, note) in warnings.items():
             print(f"{feat:<10} | {ver:<7} | {note}")
-            
-##################
-# Help functions #
-##################
+
+def modbench(module_name):
+    """
+    Measures time and memory usage for a module import.
+    Returns a tuple (seconds, memory_kb).
+    """
+    import importlib
+    start_time = time.perf_counter()
+    tracemalloc.start()
+    try:
+        importlib.import_module(module_name)
+    except Exception as e:
+        tracemalloc.stop()
+        return f"Failed to import {module_name}: {e}"
+    current, peak = tracemalloc.get_traced_memory()
+    tracemalloc.stop()
+    elapsed = time.perf_counter() - start_time
+    return {"module": module_name, "seconds_to_import": round(elapsed, 4), "memory_kb": round(peak / 1024, 2)}
+
+def modorigin(module_name):
+    """
+    Determine the origin of where a module came from.
+    (For modules that must be downloaded, you must
+    download this module first to use this function.)
+    """
+
+    import importlib.util, sys, os, pkgutil
+
+    spec = importlib.util.find_spec(module_name)
+    if spec is None:
+        return {
+            "module": module_name,
+            "origin_class": "unknown",
+            "path": None,
+            "details": "Module not found"
+        }
+
+    origin = spec.origin
+    submodule_paths = spec.submodule_search_locations
+
+    # --------------------------------------------------------
+    # CHILD HELPERS (all must start with _)
+    # --------------------------------------------------------
+
+    def _is_builtin():
+        return origin == "built-in"
+
+    def _is_frozen():
+        return origin.startswith("<frozen")
+
+    def _is_namespace_package():
+        return submodule_paths is not None and origin is None
+
+    def _is_c_extension():
+        return origin.endswith((".pyd", ".so", ".dll"))
+
+    def _is_zip():
+        return (".zip" in (origin or "")) or (".pyz" in (origin or ""))
+
+    def _is_editable_install():
+        # editable installs produce an .egg-link file in site-packages
+        try:
+            pkg = pkgutil.get_loader(module_name)
+            if pkg is None:
+                return False
+            filename = getattr(pkg, "filename", "")
+            return filename.endswith(".egg-link")
+        except Exception:
+            return False
+
+    def _is_wheel_based():
+        return ".dist-info" in (origin or "")
+
+    def _is_pip_install():
+        if _is_editable_install():
+            return True
+        if _is_wheel_based():
+            return True
+
+        # Main pip locations
+        pip_keywords = [
+            "site-packages",
+            "dist-packages",
+            ".dist-info",
+            ".egg-info",
+            "pipx",
+            "venv",
+        ]
+
+        return any(key in (origin or "").replace("\\", "/") for key in pip_keywords)
+
+    def _stdlib_root():
+        return os.path.dirname(os.__file__).replace("\\", "/")
+
+    def _is_stdlib():
+        if _is_builtin():
+            return False
+        if not origin or not os.path.isfile(origin):
+            return False
+
+        std_root = _stdlib_root()
+        return origin.replace("\\", "/").startswith(std_root)
+
+    def _is_user_module():
+        # Anything NOT stdlib, NOT pip, NOT builtin, NOT frozen
+        if (
+            not _is_builtin()
+            and not _is_frozen()
+            and not _is_stdlib()
+            and not _is_pip_install()
+            and not _is_namespace_package()
+        ):
+            return True
+        return False
+
+    # --------------------------------------------------------
+    # CLASSIFICATION LOGIC
+    # --------------------------------------------------------
+
+    if _is_builtin():
+        return {
+            "module": module_name,
+            "origin_class": "builtin",
+            "path": None,
+            "details": "Compiled into Python interpreter"
+        }
+
+    if _is_frozen():
+        return {
+            "module": module_name,
+            "origin_class": "frozen",
+            "path": origin,
+            "details": "Frozen module (PyInstaller/Nuitka)"
+        }
+
+    if _is_namespace_package():
+        return {
+            "module": module_name,
+            "origin_class": "namespace-package",
+            "path": list(submodule_paths),
+            "details": "Module has no physical file; namespace package"
+        }
+
+    if _is_c_extension():
+        return {
+            "module": module_name,
+            "origin_class": "c-extension",
+            "path": origin,
+            "details": "Compiled C extension (.pyd / .so)"
+        }
+
+    if _is_zip():
+        return {
+            "module": module_name,
+            "origin_class": "zipimport",
+            "path": origin,
+            "details": "Loaded from .pyz/.zip archive"
+        }
+
+    if _is_editable_install():
+        return {
+            "module": module_name,
+            "origin_class": "editable-pip-install",
+            "path": origin,
+            "details": "Editable pip install (egg-link)"
+        }
+
+    if _is_wheel_based():
+        return {
+            "module": module_name,
+            "origin_class": "wheel-installed",
+            "path": origin,
+            "details": "Module installed from a wheel distribution"
+        }
+
+    if _is_pip_install():
+        return {
+            "module": module_name,
+            "origin_class": "pip-installed",
+            "path": origin,
+            "details": "Installed via pip (site-packages/dist-packages)"
+        }
+
+    if _is_stdlib():
+        return {
+            "module": module_name,
+            "origin_class": "stdlib",
+            "path": origin,
+            "details": "Part of Python standard library"
+        }
+
+    if _is_user_module():
+        return {
+            "module": module_name,
+            "origin_class": "user-module",
+            "path": origin,
+            "details": "User-created module from local project directory"
+        }
+
+    # Fallback
+    return {
+        "module": module_name,
+        "origin_class": "unknown",
+        "path": origin,
+        "details": "Unable to classify module origin"
+    }
 
 def easter_egg(xrghzqxrghzq=None):
     "??????????"
-    a= '''          #   #  #####  #       #        ##
-          #   #  #      #       #       #  #
-          #####  #####  #       #      #    #
-          #   #  #      #       #       #  #
-          #   #  #####  #####   #####    ##
-
-      #           #   ##    ####    #      ###    #
-       #    #    #   #  #   #   #   #      #  #   #
-        #   #   #   #    #  ####    #      #  #   #
-         # # # #     #  #   #  #    #      #  #   
-          #   #       ##    #   #   #####  ###    #
-     
-                        #####     #
-                       #     #   #
-                       #     #  #
-                        #####  #
-                        ######
-                        # #
-                        # #
-                       #  #
-                       #  #
-                       #  #
-                         # #
-                        #   #
-                       #     #'''
+    a= '''╔═══════════════════════════════════════╗
+║ ███╗   ███╗ ██████╗ ██████╗ ██╗  ██╗  ║
+║ ████╗ ████║██╔═══██╗██╔══██╗╚██╗██╔╝  ║
+║ ██╔████╔██║██║   ██║██║  ██║ ╚███╔╝   ║
+║ ██║╚██╔╝██║██║   ██║██║  ██║ ██╔██╗   ║
+║ ██║ ╚═╝ ██║╚██████╔╝██████╔╝██╔╝ ██╗  ║
+║ ╚═╝     ╚═╝ ╚═════╝ ╚═════╝ ╚═╝  ╚═╝  ║
+║              M  O  D  X               ║
+╚═══════════════════════════════════════╝
+'''
     if xrghzqxrghzq == "abc":
         print(a)
     else:
@@ -978,79 +1168,185 @@ def easter_egg(xrghzqxrghzq=None):
         sys.exit("!)@(#$&*%^&#R&#$)!!%$@&)#@*)^!$#&!%*^)!$@#)%!$")
         quit()
 
-def modx_help():
+def revdeps(module_name):
     """
-    Show full ModX help including all functions and example usage.
+    Prints a list of modules that import given module.
+    Scans both standard library and installed third-party packages.
     """
-    help_text = """
-ModX — The Python Module Universe
-=================================
+    import builtins
+    import ast
+    
+    # Check if module exists first
+    spec = importlib.util.find_spec(module_name)
+    if not spec:
+        print(f"Module '{module_name}' not found.")
+        return
+    
+    print(f"REVERSE DEPENDENCY SCAN: {module_name}")
+    print("=" * 50)
+    
+    # Track found modules
+    found_modules = []
+    
+    def _has_import_of_target(source_code, target_module):
+        """Check if source code actually imports the target module using AST."""
+        try:
+            tree = ast.parse(source_code)
+            for node in ast.walk(tree):
+                # Check for 'import target_module'
+                if isinstance(node, ast.Import):
+                    for alias in node.names:
+                        if alias.name == target_module:
+                            return True
+                # Check for 'from target_module import ...'
+                elif isinstance(node, ast.ImportFrom):
+                    if node.module == target_module:
+                        return True
+            return False
+        except SyntaxError:
+            # Fallback to regex for syntax errors
+            import re
+            # More precise regex patterns
+            patterns = [
+                rf'^import\s+{re.escape(target_module)}\s*($|#|as)',
+                rf'^from\s+{re.escape(target_module)}\s+import',
+            ]
+            for pattern in patterns:
+                if re.search(pattern, source_code, re.MULTILINE):
+                    return True
+            return False
+    
+    # Scan standard library modules from our master list
+    print("Scanning standard library...")
+    stdlib_found = []
+    builtins._import_ = _original_import
+    
+    try:
+        for mod in modules:
+            try:
+                spec = importlib.util.find_spec(mod)
+                if spec and spec.origin and os.path.exists(spec.origin) and spec.origin.endswith('.py'):
+                    with open(spec.origin, 'r', encoding='utf-8', errors='ignore') as f:
+                        content = f.read()
+                    
+                    # Use AST to check for actual imports, not just string matching
+                    if _has_import_of_target(content, module_name):
+                        stdlib_found.append(mod)
+                        found_modules.append(f"stdlib: {mod}")
+            except (ImportError, FileNotFoundError, PermissionError, UnicodeDecodeError):
+                continue
+    finally:
+        builtins._import_ = _tracking_import
+    
+    # Scan third-party packages
+    print("Scanning third-party packages...")
+    third_party_found = []
+    builtins._import_ = _original_import
+    
+    try:
+        for finder, name, ispkg in pkgutil.iter_modules():
+            if (name not in modules and 
+                name not in sys.builtin_module_names and
+                name != '__main__' and
+                not name.startswith('__') and
+                name.isidentifier()):
+                
+                try:
+                    spec = importlib.util.find_spec(name)
+                    if (spec is not None and 
+                        hasattr(spec, 'origin') and 
+                        spec.origin is not None and 
+                        os.path.exists(spec.origin) and 
+                        spec.origin.endswith('.py')):
+                        
+                        with open(spec.origin, 'r', encoding='utf-8', errors='ignore') as f:
+                            content = f.read()
+                        
+                        # Use AST to check for actual imports
+                        if _has_import_of_target(content, module_name):
+                            third_party_found.append(name)
+                            found_modules.append(f"third-party: {name}")
+                except (ImportError, FileNotFoundError, PermissionError, UnicodeDecodeError, AttributeError):
+                    continue
+    finally:
+        builtins._import_ = _tracking_import
+    
+    # Display results
+    if found_modules:
+        print(f"\nMODULES THAT IMPORT '{module_name}':")
+        print("-" * 40)
+        for module in found_modules:
+            print(f"  • {module}")
+        print(f"\nTOTAL: {len(found_modules)} modules depend on {module_name}")
+        print(f"  - Standard Library: {len(stdlib_found)}")
+        print(f"  - Third-Party: {len(third_party_found)}")
+    else:
+        print(f"\nNo modules found that import '{module_name}'")
+        
+# --- Auto Help System 2.0 (replacement) ---
+HIDE_FROM_HELP = {"easter_egg"}  # add any other names you want hidden
 
-Functions:
-----------
+def modxhelp(export=None, compact=False, banner=True):
+    """
+    Auto-generate help text for ModX functions.
+    - export: if filename given, export Markdown help.
+    - compact: if True, show single-line summaries only.
+    - banner: if False, don't print the ASCII banner.
+    Hides internal functions.
+    """
+    import inspect, time
 
-import_all()
-    Import almost every standard library module at once.
-    Example: modx.import_all()
+    # Optional tiny banner (no version inside art)
+    if banner:
+        print("ModX — Auto Help System 2.0")
+        print("=" * 32)
 
-import_external()
-    Import all installed third-party modules.
-    Example: modx.import_external()
+    frame_globals = globals()
+    funcs = []
+    for name, obj in sorted(frame_globals.items()):
+        # Skip private, hidden, non-functions, and non-callables defined in this module
+        if name.startswith("_") or name in HIDE_FROM_HELP:
+            continue
+        # include functions and callables defined in this module only
+        if inspect.isfunction(obj) and getattr(obj, "__module__", None) == __name__:
+            # get nicely formatted signature (safe)
+            try:
+                sig = str(inspect.signature(obj))
+            except Exception:
+                sig = "(...)"
+            doc = (obj.__doc__ or "").strip().splitlines()
+            short = doc[0].strip() if doc else "(no short description)"
+            longdoc = "\n".join(doc[1:]).strip() if len(doc) > 1 else ""
+            funcs.append({"name": name, "sig": sig, "short": short, "long": longdoc})
 
-import_screen()
-    Import common screen/GUI/game modules if available (pygame, turtle, tkinter, etc.).
-    Example: modx.import_screen()
+    # Print help
+    lines = []
+    for item in funcs:
+        if compact:
+            lines.append(f"{item['name']}{item['sig']} — {item['short']}")
+        else:
+            lines.append(f"{item['name']}{item['sig']}")
+            lines.append(f"  {item['short']}")
+            if item["long"]:
+                for l in item["long"].splitlines():
+                    lines.append("    " + l)
+            lines.append("")  # blank line between entries
 
-import_letter(letter)
-    Import every standard library module starting with a given letter.
-    Example: modx.import_letter('t')
+    text = "\n".join(lines).rstrip("\n")  # rstrip to avoid trailing blanklines
+    print(text)
 
-import_random(n)
-    Import n random standard library modules.
-    Example: modx.import_random(5)
-
-list_importall()
-    Return a list of modules that import_all() would load.
-    Example: modx.list_importall()
-
-modules_loaded()
-    Show how many total modules are currently loaded in sys.modules.
-    Example: modx.modules_loaded()
-
-dependencies()
-    Show what other modules a specific module depends on without importing it.
-    Example: modx.dependencies("random")
-
-imported()
-    Show ALL modules imported after ModX loaded (user + ModX + dependencies).
-    Example: modx.imported()
-
-modx_imported()
-    Show ONLY the modules imported directly via ModX functions (excluding dependencies).
-    Example: modx.modximported()
-
-nonimported()
-    Return a list of standard library modules not yet imported.
-    Example: modx.nonimported()
-
-info(module_name)
-    Show information about a module.
-    Example: modx.info('random')
-
-search_modules(keyword)
-    Search for modules whose names contain the keyword.
-    Example: modx.search_modules('html')
-
-is_imported(module_name)
-    Check if a module is currently imported.
-    Example: modx.isimported('random')
-
-vcompat(module_name, python_version)
-    Check if a module works with different Python versions
-    Example: modx.vcompat('pygame')
-
-modx_help()
-    Show this help screen.
-    Example: modx.modxhelp()
-"""
-    print(help_text)
+    # Optional Markdown export
+    if export:
+        try:
+            md_lines = [f"# ModX - Auto Help (generated) - {time.strftime('%Y-%m-%d')}\n"]
+            for item in funcs:
+                md_lines.append(f"## {item['name']}{item['sig']}\n")
+                md_lines.append(f"{item['short']}\n")
+                if item["long"]:
+                    md_lines.append(item["long"] + "\n")
+            md_text = "\n".join(md_lines)
+            with open(export, "w", encoding="utf-8") as fh:
+                fh.write(md_text)
+            print(f"modx_help: exported Markdown to {export}")
+        except Exception as e:
+            print(f"modx_help: failed to export '{export}': {e}")
